@@ -15,5 +15,12 @@ class ComplexAdd(VectorizedComplexScalarOp):
         return string
 
     def DiffT(self, v, gradin):
+        from keopscore.formulas.complex.ComplexSum import ComplexSum
+
         f, g = self.children
-        return ComplexAdd(f.DiffT(v, gradin), g.DiffT(v, gradin))
+        if f.dim == 2 and g.dim > 2:
+            return ComplexAdd(f.DiffT(v, ComplexSum(gradin)), g.DiffT(v, gradin))
+        elif g.dim == 2 and f.dim > 2:
+            return ComplexAdd(f.DiffT(v, gradin), g.DiffT(v, ComplexSum(gradin)))
+        else:
+            return ComplexAdd(f.DiffT(v, gradin), g.DiffT(v, gradin))
